@@ -7,7 +7,7 @@ import pathlib
 import webbrowser
 
 import txt
-import webcli
+import webagt
 from rich.pretty import pprint
 
 import web
@@ -49,7 +49,7 @@ class MF:
         add_arg("uri", help="address of the resource")
 
     def run(self, stdin, log):
-        pprint(webcli.get(self.uri).mf2json.data)
+        pprint(webagt.get(self.uri).mf2json.data)
         return 0
 
 
