@@ -16,7 +16,7 @@ from pathlib import Path
 
 import newmath
 import toml
-import webcli
+import webagt
 from rich.console import Console
 
 from .. import templating
@@ -457,7 +457,7 @@ class Machine(MachineBase):
             for domain, obj in sites.items():
                 domain = domain.replace("_", ".")
                 console.print(f"Pointing https://{domain} to `{obj}`")
-                d = webcli.uri.parse(domain)
+                d = webagt.uri.parse(domain)
                 registrar.create_record(
                     f"{d.domain}.{d.suffix}", self.address, d.subdomain
                 )
